@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2017 Philip Nienhuis
+## Copyright (C) 2009-2018 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -35,6 +35,8 @@
 ## @var{xls} must be a valid pointer struct created earlier by xlsopen.
 ##
 ## @var{wsh} can be a number or string (max. 31 chars).
+## If it is numeric it refers to the position in the total sheet stack incl.
+## e.g., chartsheets.
 ## In case of a yet non-existing Excel file, the first worksheet will be
 ## used & named according to @var{wsh} - extra empty worksheets that Excel
 ## creates by default are deleted.
@@ -138,6 +140,8 @@ function [ xls, rstatus ] = oct2xls (obj, xls, wsh=1, crange="", spsh_opts=[])
   ## Check worksheet ptr
   if (! (ischar (wsh) || isnumeric (wsh)))
     error ("Integer (index) or text (wsh name) expected for arg # 3\n");
+  elseif (isempty (wsh))
+    wsh = 1;
   endif
 
   ## Check range
@@ -174,10 +178,13 @@ function [ xls, rstatus ] = oct2xls (obj, xls, wsh=1, crange="", spsh_opts=[])
   endif
 
   ## Convert to UTF-8
-  ## FIXME: Replace with the following when unicode2native is available:
-  ##        obj = tidyxml (obj, @(str) unicode2native (str, "UTF-8"));
   if (! strcmp (xls.xtype, "COM") && (spsh_opts.convert_utf))
-    obj = tidyxml (obj, @unicode2utf8);
+    if (exist ("native2unicode", "file"))
+      conv_fcn = @(str) unicode2native (native2unicode (uint8 (str)), "UTF-8");
+    else
+      conv_fcn = @unicode2utf8;
+    endif
+    obj = tidyxml (obj, conv_fcn);
   endif
   
   ## Select interface to be used
