@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2017 Philip Nienhuis
+## Copyright (C) 2009-2018 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -129,6 +129,8 @@ function [ rawarr, ods, rstatus ] = ods2oct (ods, wsh=1, datrange=[], spsh_opts=
   ## Check worksheet ptr
   if (! (ischar (wsh) || isnumeric (wsh)))
     error ("Integer (index) or text (wsh name) expected for arg # 2\n");
+  elseif (isempty (wsh))
+    wsh = 1;
   endif
   ## Check range
   if (! (isempty (datrange) || ischar (datrange)))
@@ -185,10 +187,10 @@ function [ rawarr, ods, rstatus ] = ods2oct (ods, wsh=1, datrange=[], spsh_opts=
     ## Read ods file tru Java & UNO
     [rawarr, ods, rstatus] = __UNO_spsh2oct__ (ods, wsh, datrange, spsh_opts);
   elseif (strcmp (ods.xtype, "OCT"))
-    if (strcmpi (ods.app, 'ods'))
+    if (strcmpi (ods.app, "ods"))
       ## Read ods file tru native Octave
       [rawarr, ods, rstatus] = __OCT_ods2oct__ (ods, wsh, datrange, spsh_opts);
-    elseif (strcmpi (ods.app, 'gnumeric'))
+    elseif (strcmpi (ods.app, "gnumeric"))
       ## Read gnumeric. Gnumeric does not support formula evaluation nor supports
       ## cached values. Stripping output is processed below, spsh_opts is ignored
       [rawarr, ods, rstatus] = __OCT_gnm2oct__ (ods, wsh, datrange);
@@ -208,10 +210,13 @@ function [ rawarr, ods, rstatus ] = ods2oct (ods, wsh=1, datrange=[], spsh_opts=
 
   ## Convert from UTF-8 and strip characters that are not supported by Octave
   ## (any chars < 32 or > 255).
-  ## FIXME: Replace with the following when native2unicode is available:
-  ##        rawarr = tidyxml (rawarr, @(str) native2unicode (str, "UTF-8"));
   if (spsh_opts.convert_utf)
-    rawarr = tidyxml (rawarr, @utf82unicode);
+    if (exist ("native2unicode", "file"))
+      conv_fcn = @(str) unicode2native (native2unicode (str, "UTF-8"));
+    else
+      conv_fcn = @utf82unicode;
+    endif
+    rawarr = tidyxml (rawarr, conv_fcn);
   endif
 
   rstatus = ! isempty (rawarr);
