@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2017 Philip Nienhuis
+## Copyright (C) 2009-2018 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -97,7 +97,7 @@ function [ ods ] = odsclose (ods, varargs)
 
   elseif (strcmp (ods.xtype, "OCT"))
     ## Native Octave
-    ods = __OCT_spsh_close__ (ods);
+    ods = __OCT_spsh_close__ (ods, "odsclose");
 
   ##elseif ---- < Other interfaces here >
 
