@@ -1,4 +1,4 @@
-## Copyright (C) 2012-2017 Philip Nienhuis
+## Copyright (C) 2012-2018 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -21,9 +21,9 @@
 
 function [sh_names] = __POI_spsh_info__ (xls)
 
-  persistent cblnk; cblnk = __java_get__ ("org.apache.poi.ss.usermodel.Cell", "CELL_TYPE_BLANK");
   sh_cnt = xls.workbook.getNumberOfSheets();
-  sh_names = cell (sh_cnt, 2); nsrows = zeros (sh_cnt, 1);
+  sh_names = cell (sh_cnt, 2);
+  nsrows = zeros (sh_cnt, 1);
   for ii=1:sh_cnt
     sh = xls.workbook.getSheetAt (ii-1);         # Java POI starts counting at 0 
     sh_names(ii, 1) = char (sh.getSheetName());
