@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2017 Philip Nienhuis
+## Copyright (C) 2009-2018 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -118,7 +118,7 @@ function [ xls ] = xlsclose (xls, varargin)
     xls = __UNO_spsh_close__ (xls, force);
 
   elseif (strcmp (xls.xtype, "OCT"))
-    xls = __OCT_spsh_close__ (xls);
+    xls = __OCT_spsh_close__ (xls, "xlsclose");
 
   ## elseif   <other interfaces here>
 
