@@ -18,7 +18,7 @@
 
 %% Check EOF w/o preceding EOL & text fields in 1st column disguised as numeric str
 %!test
-%! f = tmpnam ();
+%! f = tempname ();
 %! fid = fopen (f, 'w+');
 %! fprintf (fid, "\"1\"");
 %! fclose (fid);
@@ -27,7 +27,7 @@
 %! assert (s, "1");
 
 %!test
-%! f = tmpnam ();
+%! f = tempname ();
 %! csvwrite(f, "\"1\",2", "DELIMITER", "");
 %! s = csv2cell(f);
 %! unlink (f);
@@ -35,7 +35,7 @@
 %! assert (s{2}, 2);
 
 %!test
-%! f = tmpnam ();
+%! f = tempname ();
 %! csvwrite(f, "3,\"1\"", "DELIMITER", "");
 %! s = csv2cell(f);
 %! unlink (f);
@@ -45,7 +45,7 @@
 
 %% Check proper string protection
 %!test
-%! f = tmpnam ();
+%! f = tempname ();
 %! fid = fopen (f, 'w+');
 %! str = ['01/03/2012,"H (Mar, 12)",26.750000,2584' "\n"];
 %! str = [str '"01/04/2012",H (Mar, 12),2330' "\n"];
@@ -64,7 +64,7 @@
 
 %% Check separator and string protection arguments
 %!test
-%! f = tmpnam ();
+%! f = tempname ();
 %! fid = fopen (f, 'w+');
 %! str = ['01/03/2012;$H (Mar; 12)$;26.750000;2584' "\n"];
 %! str = [str '$01/04/2012$;H (Mar; 12);2330' "\n"];
@@ -83,7 +83,7 @@
 
 %% Check headerlines,
 %!test
-%! f = tmpnam ();
+%! f = tempname ();
 %! fid = fopen (f, 'w+');
 %! fprintf (fid, "A, B\n 1, 2\n 3, 4\n 5, 6\n");
 %! fclose (fid);
@@ -103,7 +103,7 @@
 
 %% Check surplus headerlines w EOF before final EOL
 %!test
-%! f = tmpnam ();
+%! f = tempname ();
 %! fid = fopen (f, 'w+');
 %! fprintf (fid, "A, B\n 1, 2\n 3, 4\n 5, 6");
 %! fclose (fid);
@@ -113,7 +113,7 @@
 
 %% Check if csv2cell ignores trailing CR's in cells
 %!test
-%! f = tmpnam ();
+%! f = tempname ();
 %! fid = fopen (f, 'w+');
 %! fprintf (fid, "a\r\n1\r\nc\n4\n");
 %! fclose (fid);
@@ -124,7 +124,7 @@
 
 %% Check spreadsheet style range arg
 %!test
-%! f = tmpnam ();
+%! f = tempname ();
 %! fid = fopen (f, 'w+');
 %! fprintf (fid, '1,2,3\n11,12,13,"14",15,16\n,22\n31,32,"33",34\n41,"42",,44,45\n51,52,53');
 %! fclose (fid);
@@ -136,7 +136,7 @@
 
 %% Check files with uneven line length w/o range arg
 %!test
-%! f = tmpnam ();
+%! f = tempname ();
 %! fid = fopen (f, 'w+');
 %! fprintf (fid, 'a,b,c,d,e,f\n11,12,13,"14",15,16\n,22\n31,32,"33",34\n41,"42",,44,45\n51,52,53');
 %! fclose (fid);
@@ -151,7 +151,7 @@
 
 %% Check ":" separator
 %!test
-%! f = tmpnam ();
+%! f = tempname ();
 %! fid = fopen (f, 'w+');
 %! fprintf (fid, "1:2\n3:4\n5:6");
 %! fclose (fid);
@@ -161,7 +161,7 @@
 
 %% Check ":" separator and spreadsheet style range combi
 %!test
-%! f = tmpnam ();
+%! f = tempname ();
 %! fid = fopen (f, 'w+');
 %! fprintf (fid, "1:2:3\n4:5:6\n7:8:9\n");
 %! fclose (fid);
@@ -386,7 +386,7 @@ separators.)\n\
   for (int i = 0, len = str.length (); i <= len; i++)
     if (i == len || ((str[i] == sep || str[i] == 10) && ! inside))
       nbcolumns++;
-    else if ((inside) && (str[i] == prot) && ((i < len) && (str[i+1] == prot)))
+    else if ((inside) && (str[i] == prot) && ((i+1 < len) && (str[i+1] == prot)))
       ++i;
     else if (str[i] == prot)
       inside = !inside;
@@ -475,7 +475,7 @@ separators.)\n\
                 break;
               }
             /* Check for last char to be 13 (CR) and remove if found */
-            if (word[word.length ()-1] == char(13))
+            if (word.length () && word[word.length ()-1] == char(13))
                 word.resize (word.size () - 1);
             /* Check if scalar */
             const char *word_str = word.c_str ();
@@ -491,7 +491,7 @@ separators.)\n\
             word = "";
             oinside = false;
           }
-          else if ((inside) && (str[k] == prot) && ((k < len) && (str[k+1] == prot)))
+          else if ((inside) && (str[k] == prot) && ((k+1 < len) && (str[k+1] == prot)))
             {
               /* Inside a string */
               word += prot;
